From 0f80162dcf0f669630e8e338e358910b95cac196 Mon Sep 17 00:00:00 2001
From: Dave Houlton <euclid@lindenlab.com>
Date: Fri, 28 Aug 2020 10:33:48 -0600
Subject: [PATCH] SL-13768 de-obfuscate cloud/sky vertex shaders

---
 .../shaders/class1/deferred/cloudsV.glsl      | 78 ++++++++-----------
 .../shaders/class1/deferred/skyV.glsl         | 64 +++++++--------
 .../shaders/class2/windlight/cloudsV.glsl     | 76 ++++++++----------
 .../shaders/class2/windlight/skyV.glsl        | 64 +++++++--------
 4 files changed, 123 insertions(+), 159 deletions(-)

diff --git a/indra/newview/app_settings/shaders/class1/deferred/cloudsV.glsl b/indra/newview/app_settings/shaders/class1/deferred/cloudsV.glsl
index b9c19981d22..bf4e6b8e614 100644
--- a/indra/newview/app_settings/shaders/class1/deferred/cloudsV.glsl
+++ b/indra/newview/app_settings/shaders/class1/deferred/cloudsV.glsl
@@ -94,75 +94,66 @@ void main()
 	vary_texcoord3 = vary_texcoord1 * 16.;
 
 	// Get relative position
-	vec3 P = position.xyz - camPosLocal.xyz + vec3(0,50,0);
+	vec3 rel_pos = position.xyz - camPosLocal.xyz + vec3(0,50,0);
 
-    altitude_blend_factor = clamp((P.y + 512.0) / max_y, 0.0, 1.0);
+    altitude_blend_factor = clamp((rel_pos.y + 512.0) / max_y, 0.0, 1.0);
 
 	// Set altitude
-	if (P.y > 0.)
+	if (rel_pos.y > 0.)
 	{
-		P *= (max_y / P.y);
+		rel_pos *= (max_y / rel_pos.y);
 	}
 	else
 	{
 		altitude_blend_factor = 0; // SL-11589 Fix clouds drooping below horizon
-		P *= (-32000. / P.y);
+		rel_pos *= (-32000. / rel_pos.y);
 	}
 
 	// Can normalize then
-	vec3 Pn = normalize(P);
-	float  Plen = length(P);
+	vec3 rel_pos_norm = normalize(rel_pos);
+	float  rel_pos_len = length(rel_pos);
 
 	// Initialize temp variables
-	vec4 temp1 = vec4(0.);
-	vec4 temp2 = vec4(0.);
-	vec4 blue_weight;
-	vec4 haze_weight;
-	//vec4 sunlight = (sun_up_factor == 1) ? sunlight_color : moonlight_color;
 	vec4 sunlight = sunlight_color;
 	vec4 light_atten;
 
-    float dens_mul = density_multiplier;
-
-	// Sunlight attenuation effect (hue and brightness) due to atmosphere
+    // Sunlight attenuation effect (hue and brightness) due to atmosphere
 	// this is used later for sunlight modulation at various altitudes
-	light_atten = (blue_density + vec4(haze_density * 0.25)) * (dens_mul * max_y);
+	light_atten = (blue_density + vec4(haze_density * 0.25)) * (density_multiplier * max_y);
 
 	// Calculate relative weights
-	temp1 = abs(blue_density) + vec4(abs(haze_density));
-	blue_weight = blue_density / temp1;
-	haze_weight = haze_density / temp1;
+	vec4 combined_haze = abs(blue_density) + vec4(abs(haze_density));
+    vec4 blue_weight = blue_density / combined_haze;
+	vec4 haze_weight = haze_density / combined_haze;
 
-	// Compute sunlight from P & lightnorm (for long rays like sky)
-	temp2.y = max(0., max(0., Pn.y) * 1.0 + lightnorm.y );
-	temp2.y = 1. / temp2.y;
-	sunlight *= exp( - light_atten * temp2.y);
+	// Compute sunlight from rel_pos & lightnorm (for long rays like sky)
+    float off_axis = 1.0 / max(1e-6, max(0., rel_pos_norm.y) + lightnorm.y); 
+    sunlight *= exp( - light_atten * off_axis);
 
 	// Distance
-	temp2.z = Plen * dens_mul;
+	float density_dist = rel_pos_len * density_multiplier;
 
 	// Transparency (-> temp1)
 	// ATI Bugfix -- can't store temp1*temp2.z in a variable because the ati
 	// compiler gets confused.
-	temp1 = exp(-temp1 * temp2.z);
+	combined_haze = exp(-combined_haze * density_dist);
 
 
 	// Compute haze glow
-	temp2.x = dot(Pn, lightnorm.xyz);
-	temp2.x = 1. - temp2.x;
-		// temp2.x is 0 at the sun and increases away from sun
-	temp2.x = max(temp2.x, .001);	
+    float haze_glow = 1.0 - dot(rel_pos_norm, lightnorm.xyz);
+    // haze_glow is 0 at the sun and increases away from sun
+	haze_glow = max(haze_glow, .001);	
 		// Set a minimum "angle" (smaller glow.y allows tighter, brighter hotspot)
-	temp2.x *= glow.x;
+	haze_glow *= glow.x;
 		// Higher glow.x gives dimmer glow (because next step is 1 / "angle")
-	temp2.x = pow(temp2.x, glow.z);
+	haze_glow = pow(haze_glow, glow.z);
 		// glow.z should be negative, so we're doing a sort of (1 / "angle") function
 
-    temp2.x *= sun_moon_glow_factor;
+    haze_glow *= sun_moon_glow_factor;
 
 	// Add "minimum anti-solar illumination"
     // For sun, add to glow.  For moon, remove glow entirely. SL-13768
-    temp2.x = (sun_moon_glow_factor < 1.0) ? 0.0 : (temp2.x + 0.25);
+    haze_glow = (sun_moon_glow_factor < 1.0) ? 0.0 : (haze_glow + 0.25);
 
 	// Increase ambient when there are more clouds
 	vec4 tmpAmbient = ambient_color;
@@ -173,23 +164,22 @@ void main()
 
 	// Haze color below cloud
 	vec4 additiveColorBelowCloud = (	  blue_horizon * blue_weight * (sunlight + tmpAmbient)
-				+ (haze_horizon * haze_weight) * (sunlight * temp2.x + tmpAmbient)
+				+ (haze_horizon * haze_weight) * (sunlight * haze_glow + tmpAmbient)
 			 );	
 
 	// CLOUDS
-	temp2.y = max(0., lightnorm.y * 2.);
-	temp2.y = 1. / temp2.y;
-	sunlight *= exp( - light_atten * temp2.y);
+	off_axis = 1.0 / max(1e-6, lightnorm.y * 2.);
+	sunlight *= exp( - light_atten * off_axis);
 
 	// Cloud color out
-	vary_CloudColorSun = (sunlight * temp2.x) * cloud_color;
+	vary_CloudColorSun = (sunlight * haze_glow) * cloud_color;
 	vary_CloudColorAmbient = tmpAmbient * cloud_color;
 	
 	// Attenuate cloud color by atmosphere
-	temp1 = sqrt(temp1);	//less atmos opacity (more transparency) below clouds
-	vary_CloudColorSun *= temp1;
-	vary_CloudColorAmbient *= temp1;
-	vec4 oHazeColorBelowCloud = additiveColorBelowCloud * (1. - temp1);
+	combined_haze = sqrt(combined_haze);	//less atmos opacity (more transparency) below clouds
+	vary_CloudColorSun *= combined_haze;
+	vary_CloudColorAmbient *= combined_haze;
+	vec4 oHazeColorBelowCloud = additiveColorBelowCloud * (1. - combined_haze);
 
 	// Make a nice cloud density based on the cloud_shadow value that was passed in.
 	vary_CloudDensity = 2. * (cloud_shadow - 0.25);
@@ -94,75 +94,66 @@ void main()
 
-	// Transparency (-> temp1)
-	// ATI Bugfix -- can't store temp1*temp2.z in a variable because the ati
+	// Transparency (-> combined_haze)
+	// ATI Bugfix -- can't store combined_haze*density_dist in a variable because the ati
 	// compiler gets confused.
diff --git a/indra/newview/app_settings/shaders/class1/deferred/skyV.glsl b/indra/newview/app_settings/shaders/class1/deferred/skyV.glsl
index f779cf54cef..cd19fa460b1 100644
--- a/indra/newview/app_settings/shaders/class1/deferred/skyV.glsl
+++ b/indra/newview/app_settings/shaders/class1/deferred/skyV.glsl
@@ -70,77 +70,69 @@ void main()
 	gl_Position = pos;
 	
 	// Get relative position
-	vec3 P = position.xyz - camPosLocal.xyz + vec3(0,50,0);
+	vec3 rel_pos = position.xyz - camPosLocal.xyz + vec3(0,50,0);
 
 	// Set altitude
-	if (P.y > 0.)
+	if (rel_pos.y > 0.)
 	{
-		P *= (max_y / P.y);
+		rel_pos *= (max_y / rel_pos.y);
 	}
 	else
 	{
-		P *= (-32000. / P.y);
+		rel_pos *= (-32000. / rel_pos.y);
 	}
 
 	// Can normalize then
-	vec3 Pn = normalize(P);
+	vec3 rel_pos_norm = normalize(rel_pos);
 
-	float Plen = length(P);
+	float rel_pos_len = length(rel_pos);
 
 	// Initialize temp variables
-	vec4 temp1 = vec4(0.);
-	vec4 temp2 = vec4(0.);
-	vec4 blue_weight;
-	vec4 haze_weight;
 	vec4 sunlight = (sun_up_factor == 1) ? sunlight_color : moonlight_color;
 	vec4 light_atten;
 
-    float dens_mul = density_multiplier;
-
 	// Sunlight attenuation effect (hue and brightness) due to atmosphere
 	// this is used later for sunlight modulation at various altitudes
-	light_atten = (blue_density + vec4(haze_density * 0.25)) * (dens_mul * max_y);
+	light_atten = (blue_density + vec4(haze_density * 0.25)) * (density_multiplier * max_y);
 
 	// Calculate relative weights
-	temp1 = abs(blue_density) + vec4(abs(haze_density));
-	blue_weight = blue_density / temp1;
-	haze_weight = haze_density / temp1;
+	vec4 combined_haze = abs(blue_density) + vec4(abs(haze_density));
+    vec4 blue_weight = blue_density / combined_haze;
+    vec4 haze_weight = haze_density / combined_haze;
 
-	// Compute sunlight from P & lightnorm (for long rays like sky)
-    temp2.y = max(0., max(0., Pn.y) * 1.0 + lightnorm.y );
-    temp2.y = 1. / temp2.y;
-    sunlight *= exp( - light_atten * temp2.y);
+	// Compute sunlight from rel_pos & lightnorm (for long rays like sky)
+    float off_axis = 1.0 / max(1e-6, max(0., rel_pos_norm.y) + lightnorm.y); 
+    sunlight *= exp( - light_atten * off_axis);
 
 	// Distance
-	temp2.z = Plen * dens_mul;
+	float density_dist = rel_pos_len * density_multiplier;
 
 	// Transparency (-> temp1)
     // ATI Bugfix -- can't store temp1*temp2.z in a variable because the ati
     // compiler gets confused.
-    temp1 = exp(-temp1 * temp2.z);
+    combined_haze = exp(-combined_haze * density_dist);
 
 	// Compute haze glow
-	temp2.x = dot(Pn, lightnorm.xyz);
-	temp2.x = 1. - temp2.x;
-		// temp2.x is 0 at the sun and increases away from sun
-	temp2.x = max(temp2.x, .001);	
+    float haze_glow = 1.0 - dot(rel_pos_norm, lightnorm.xyz);
+    // haze_glow is 0 at the sun and increases away from sun
+	haze_glow = max(haze_glow, .001);	
 		// Set a minimum "angle" (smaller glow.y allows tighter, brighter hotspot)
-	temp2.x *= glow.x;
+	haze_glow *= glow.x;
 		// Higher glow.x gives dimmer glow (because next step is 1 / "angle")
-	temp2.x = pow(temp2.x, glow.z);
+	haze_glow = pow(haze_glow, glow.z);
 		// glow.z should be negative, so we're doing a sort of (1 / "angle") function
 
 	// Add "minimum anti-solar illumination"
     // For sun, add to glow.  For moon, remove glow entirely. SL-13768
-    temp2.x = (sun_moon_glow_factor < 1.0) ? 0.0 : (temp2.x + 0.25);
+    haze_glow = (sun_moon_glow_factor < 1.0) ? 0.0 : (haze_glow + 0.25);
 
     vec4 color = (    blue_horizon * blue_weight * (sunlight + ambient_color)
-                + (haze_horizon * haze_weight) * (sunlight * temp2.x + ambient_color)
+                + (haze_horizon * haze_weight) * (sunlight * haze_glow + ambient_color)
              );
 
 
     // Final atmosphere additive
-    color *= (1. - temp1);
+    color *= (1. - combined_haze);
 
 	// Increase ambient when there are more clouds
 	vec4 tmpAmbient = ambient_color;
@@ -151,14 +143,14 @@ void main()
 
 	// Haze color below cloud
 	vec4 additiveColorBelowCloud = (	  blue_horizon * blue_weight * (sunlight + tmpAmbient)
-				+ (haze_horizon * haze_weight) * (sunlight * temp2.x + tmpAmbient)
+				+ (haze_horizon * haze_weight) * (sunlight * haze_glow + tmpAmbient)
 			 );	
 
 	// Attenuate cloud color by atmosphere
-	temp1 = sqrt(temp1);	//less atmos opacity (more transparency) below clouds
+	combined_haze = sqrt(combined_haze);	//less atmos opacity (more transparency) below clouds
 
 	// At horizon, blend high altitude sky color towards the darker color below the clouds
-	color += (additiveColorBelowCloud - color) * (1. - sqrt(temp1));
+	color += (additiveColorBelowCloud - color) * (1. - sqrt(combined_haze));
 
     // Haze color above cloud
 	vary_HazeColor = color;	
@@ -70,77 +70,69 @@ void main()
 
-	// Transparency (-> temp1)
-    // ATI Bugfix -- can't store temp1*temp2.z in a variable because the ati
+	// Transparency (-> combined_haze)
+    // ATI Bugfix -- can't store combined_haze*density_dist in a variable because the ati
     // compiler gets confused.
diff --git a/indra/newview/app_settings/shaders/class2/windlight/cloudsV.glsl b/indra/newview/app_settings/shaders/class2/windlight/cloudsV.glsl
index 7d736b8fcc6..e4c36ee657d 100644
--- a/indra/newview/app_settings/shaders/class2/windlight/cloudsV.glsl
+++ b/indra/newview/app_settings/shaders/class2/windlight/cloudsV.glsl
@@ -94,75 +94,66 @@ void main()
 	vary_texcoord3 = vary_texcoord1 * 16.;
 
 	// Get relative position
-	vec3 P = position.xyz - camPosLocal.xyz + vec3(0,50,0);
+	vec3 rel_pos = position.xyz - camPosLocal.xyz + vec3(0,50,0);
 
     // fade clouds beyond a certain point so the bottom of the sky dome doesn't look silly at high altitude
-    altitude_blend_factor = clamp((P.y + 512.0) / max_y, 0.0, 1.0);
+    altitude_blend_factor = clamp((rel_pos.y + 512.0) / max_y, 0.0, 1.0);
 
 	// Set altitude
-	if (P.y > 0.)
+	if (rel_pos.y > 0.)
 	{
-		P *= (max_y / P.y);
+		rel_pos *= (max_y / rel_pos.y);
 	}
 	else
 	{
-		P *= (-32000. / P.y);
+		rel_pos *= (-32000. / rel_pos.y);
 	}
 
 	// Can normalize then
-	vec3 Pn = normalize(P);
-	float  Plen = length(P);
+	vec3 rel_pos_norm = normalize(rel_pos);
+	float rel_pos_len = length(rel_pos);
 
 	// Initialize temp variables
-	vec4 temp1 = vec4(0.);
-	vec4 temp2 = vec4(0.);
-	vec4 blue_weight;
-	vec4 haze_weight;
-	//vec4 sunlight = (sun_up_factor == 1) ? sunlight_color : moonlight_color;
 	vec4 sunlight = sunlight_color;
 	vec4 light_atten;
 
-    float dens_mul = density_multiplier;
-
 	// Sunlight attenuation effect (hue and brightness) due to atmosphere
 	// this is used later for sunlight modulation at various altitudes
-	light_atten = (blue_density + vec4(haze_density * 0.25)) * (dens_mul * max_y);
+	light_atten = (blue_density + vec4(haze_density * 0.25)) * (density_multiplier * max_y);
 
 	// Calculate relative weights
-	temp1 = abs(blue_density) + vec4(abs(haze_density));
-	blue_weight = blue_density / temp1;
-	haze_weight = haze_density / temp1;
+	vec4 combined_haze = abs(blue_density) + vec4(abs(haze_density));
+    vec4 blue_weight = blue_density / combined_haze;
+    vec4 haze_weight = haze_density / combined_haze;
 
-	// Compute sunlight from P & lightnorm (for long rays like sky)
-	temp2.y = max(0., max(0., Pn.y) * 1.0 + lightnorm.y );
-	temp2.y = 1. / temp2.y;
-	sunlight *= exp( - light_atten * temp2.y);
+	// Compute sunlight from rel_pos & lightnorm (for long rays like sky)
+    float off_axis = 1.0 / max(1e-6, max(0., rel_pos_norm.y) + lightnorm.y); 
+    sunlight *= exp( - light_atten * off_axis);
 
 	// Distance
-	temp2.z = Plen * dens_mul;
+	float density_dist = rel_pos_len * density_multiplier;
 
 	// Transparency (-> temp1)
 	// ATI Bugfix -- can't store temp1*temp2.z in a variable because the ati
 	// compiler gets confused.
-	temp1 = exp(-temp1 * temp2.z);
+	combined_haze = exp(-combined_haze * density_dist);
 
 
 	// Compute haze glow
-	temp2.x = dot(Pn, lightnorm.xyz);
-	temp2.x = 1. - temp2.x;
-		// temp2.x is 0 at the sun and increases away from sun
-	temp2.x = max(temp2.x, .001);	
+    float haze_glow = 1.0 - dot(rel_pos_norm, lightnorm.xyz);
+    // haze_glow is 0 at the sun and increases away from sun
+	haze_glow = max(haze_glow, .001);	
 		// Set a minimum "angle" (smaller glow.y allows tighter, brighter hotspot)
-	temp2.x *= glow.x;
+	haze_glow *= glow.x;
 		// Higher glow.x gives dimmer glow (because next step is 1 / "angle")
-	temp2.x = pow(temp2.x, glow.z);
+	haze_glow = pow(haze_glow, glow.z);
 		// glow.z should be negative, so we're doing a sort of (1 / "angle") function
 
-    temp2.x *= sun_moon_glow_factor;
+    haze_glow *= sun_moon_glow_factor;
 
 	// Add "minimum anti-solar illumination"
     // For sun, add to glow.  For moon, remove glow entirely. SL-13768
-    temp2.x = (sun_moon_glow_factor < 1.0) ? 0.0 : (temp2.x + 0.25);
+    haze_glow = (sun_moon_glow_factor < 1.0) ? 0.0 : (haze_glow + 0.25);
 
 	// Increase ambient when there are more clouds
 	vec4 tmpAmbient = ambient_color;
@@ -173,23 +164,22 @@ void main()
 
 	// Haze color below cloud
 	vec4 additiveColorBelowCloud = (	  blue_horizon * blue_weight * (sunlight + tmpAmbient)
-				+ (haze_horizon * haze_weight) * (sunlight * temp2.x + tmpAmbient)
+				+ (haze_horizon * haze_weight) * (sunlight * haze_glow + tmpAmbient)
 			 );	
 
 	// CLOUDS
-	temp2.y = max(0., lightnorm.y * 2.);
-	temp2.y = 1. / temp2.y;
-	sunlight *= exp( - light_atten * temp2.y);
+	off_axis = 1.0 / max(1e-6, lightnorm.y * 2.);
+	sunlight *= exp( - light_atten * off_axis);
 
 	// Cloud color out
-	vary_CloudColorSun = (sunlight * temp2.x) * cloud_color;
+	vary_CloudColorSun = (sunlight * haze_glow) * cloud_color;
 	vary_CloudColorAmbient = tmpAmbient * cloud_color;
 	
 	// Attenuate cloud color by atmosphere
-	temp1 = sqrt(temp1);	//less atmos opacity (more transparency) below clouds
-	vary_CloudColorSun *= temp1;
-	vary_CloudColorAmbient *= temp1;
-	vec4 oHazeColorBelowCloud = additiveColorBelowCloud * (1. - temp1);
+	combined_haze = sqrt(combined_haze);	//less atmos opacity (more transparency) below clouds
+	vary_CloudColorSun *= combined_haze;
+	vary_CloudColorAmbient *= combined_haze;
+	vec4 oHazeColorBelowCloud = additiveColorBelowCloud * (1. - combined_haze);
 
 	// Make a nice cloud density based on the cloud_shadow value that was passed in.
 	vary_CloudDensity = 2. * (cloud_shadow - 0.25);
@@ -94,75 +94,66 @@ void main()
 
-	// Transparency (-> temp1)
-	// ATI Bugfix -- can't store temp1*temp2.z in a variable because the ati
+	// Transparency (-> combined_haze)
+	// ATI Bugfix -- can't store combined_haze*density_dist in a variable because the ati
 	// compiler gets confused.
diff --git a/indra/newview/app_settings/shaders/class2/windlight/skyV.glsl b/indra/newview/app_settings/shaders/class2/windlight/skyV.glsl
index 1361f6a11d4..1ee9c33c1a8 100644
--- a/indra/newview/app_settings/shaders/class2/windlight/skyV.glsl
+++ b/indra/newview/app_settings/shaders/class2/windlight/skyV.glsl
@@ -66,77 +66,69 @@ void main()
 	gl_Position = pos;
 	
 	// Get relative position
-	vec3 P = position.xyz - camPosLocal.xyz + vec3(0,50,0);
+	vec3 rel_pos = position.xyz - camPosLocal.xyz + vec3(0,50,0);
 
 	// Set altitude
-	if (P.y > 0.)
+	if (rel_pos.y > 0.)
 	{
-		P *= (max_y / P.y);
+		rel_pos *= (max_y / rel_pos.y);
 	}
 	else
 	{
-		P *= (-32000. / P.y);
+		rel_pos *= (-32000. / rel_pos.y);
 	}
 
 	// Can normalize then
-	vec3 Pn = normalize(P);
+	vec3 rel_pos_norm = normalize(rel_pos);
 
-	float Plen = length(P);
+	float rel_pos_len = length(rel_pos);
 
 	// Initialize temp variables
-	vec4 temp1 = vec4(0.);
-	vec4 temp2 = vec4(0.);
-	vec4 blue_weight;
-	vec4 haze_weight;
 	vec4 sunlight = (sun_up_factor == 1) ? sunlight_color : moonlight_color;
 	vec4 light_atten;
 
-    float dens_mul = density_multiplier;
-
 	// Sunlight attenuation effect (hue and brightness) due to atmosphere
 	// this is used later for sunlight modulation at various altitudes
-	light_atten = (blue_density + vec4(haze_density * 0.25)) * (dens_mul * max_y);
+	light_atten = (blue_density + vec4(haze_density * 0.25)) * (density_multiplier * max_y);
 
 	// Calculate relative weights
-	temp1 = abs(blue_density) + vec4(abs(haze_density));
-	blue_weight = blue_density / temp1;
-	haze_weight = haze_density / temp1;
+	vec4 combined_haze = abs(blue_density) + vec4(abs(haze_density));
+	vec4 blue_weight = blue_density / combined_haze;
+    vec4 haze_weight = haze_density / combined_haze;
 
-	// Compute sunlight from P & lightnorm (for long rays like sky)
-    temp2.y = max(0., max(0., Pn.y) * 1.0 + lightnorm.y );
-    temp2.y = 1. / temp2.y;
-    sunlight *= exp( - light_atten * temp2.y);
+	// Compute sunlight from rel_pos & lightnorm (for long rays like sky)
+    float off_axis = 1.0 / max(1e-6, max(0., rel_pos_norm.y) + lightnorm.y); 
+    sunlight *= exp( - light_atten * off_axis);
 
 	// Distance
-	temp2.z = Plen * dens_mul;
+	float density_dist = rel_pos_len * density_multiplier;
 
 	// Transparency (-> temp1)
     // ATI Bugfix -- can't store temp1*temp2.z in a variable because the ati
     // compiler gets confused.
-    temp1 = exp(-temp1 * temp2.z);
+    combined_haze = exp(-combined_haze * density_dist);
 
 	// Compute haze glow
-	temp2.x = dot(Pn, lightnorm.xyz);
-	temp2.x = 1. - temp2.x;
-		// temp2.x is 0 at the sun and increases away from sun
-	temp2.x = max(temp2.x, .001);	
+    float haze_glow = 1.0 - dot(rel_pos_norm, lightnorm.xyz);
+    // haze_glow is 0 at the sun and increases away from sun
+	haze_glow = max(haze_glow, .001);	
 		// Set a minimum "angle" (smaller glow.y allows tighter, brighter hotspot)
-	temp2.x *= glow.x;
+	haze_glow *= glow.x;
 		// Higher glow.x gives dimmer glow (because next step is 1 / "angle")
-	temp2.x = pow(temp2.x, glow.z);
+	haze_glow = pow(haze_glow, glow.z);
 		// glow.z should be negative, so we're doing a sort of (1 / "angle") function
 
 	// Add "minimum anti-solar illumination"
     // For sun, add to glow.  For moon, remove glow entirely. SL-13768
-    temp2.x = (sun_moon_glow_factor < 1.0) ? 0.0 : (temp2.x + 0.25);
+    haze_glow = (sun_moon_glow_factor < 1.0) ? 0.0 : (haze_glow + 0.25);
 
     vec4 color = (    blue_horizon * blue_weight * (sunlight + ambient_color)
-                + (haze_horizon * haze_weight) * (sunlight * temp2.x + ambient_color)
+                + (haze_horizon * haze_weight) * (sunlight * haze_glow + ambient_color)
              );
 
 
     // Final atmosphere additive
-    color *= (1. - temp1);
+    color *= (1. - combined_haze);
 
 	// Increase ambient when there are more clouds
 	vec4 tmpAmbient = ambient_color;
@@ -147,14 +139,14 @@ void main()
 
 	// Haze color below cloud
 	vec4 additiveColorBelowCloud = (	  blue_horizon * blue_weight * (sunlight + tmpAmbient)
-				+ (haze_horizon * haze_weight) * (sunlight * temp2.x + tmpAmbient)
+				+ (haze_horizon * haze_weight) * (sunlight * haze_glow + tmpAmbient)
 			 );	
 
 	// Attenuate cloud color by atmosphere
-	temp1 = sqrt(temp1);	//less atmos opacity (more transparency) below clouds
+	combined_haze = sqrt(combined_haze);	//less atmos opacity (more transparency) below clouds
 
 	// At horizon, blend high altitude sky color towards the darker color below the clouds
-	color += (additiveColorBelowCloud - color) * (1. - sqrt(temp1));
+	color += (additiveColorBelowCloud - color) * (1. - sqrt(combined_haze));
 
     // Haze color above cloud
     vary_HazeColor = color;
@@ -66,77 +66,69 @@ void main()
 
-	// Transparency (-> temp1)
-    // ATI Bugfix -- can't store temp1*temp2.z in a variable because the ati
+	// Transparency (-> combined_haze)
+    // ATI Bugfix -- can't store combined_haze*density_dist in a variable because the ati
     // compiler gets confused.
-- 
GitLab